@@ -2,7 +2,7 @@
 fraction.py
 this script is response for the operation in fraction.
 """
-import number_theory
+from wmath.number_theory import *
 
 
 class Fraction:
@@ -12,7 +12,7 @@ class Fraction:
     def __init__(self, molecule: int, denominator: int):
         self.__dict__['__inited'] = False
         assert type(molecule) == int and type(denominator) == int
-        _greatest_common_divisor = number_theory.greatest_common_divisor(molecule, denominator)
+        _greatest_common_divisor = greatest_common_divisor(molecule, denominator)
         self.molecule = molecule // _greatest_common_divisor
         self.denominator = denominator // _greatest_common_divisor
         self.__dict__['__inited'] = True
@@ -24,7 +24,7 @@ class Fraction:
         self.__dict__[key] = value
         if self.__dict__['__inited']:
             # dynamically adjust the fraction
-            _greatest_common_divisor = number_theory.greatest_common_divisor(
+            _greatest_common_divisor = greatest_common_divisor(
                 self.__dict__['molecule'],
                 self.__dict__['denominator'])
             self.__dict__['molecule'] = self.__dict__['molecule'] // _greatest_common_divisor
